@@ -9,8 +9,7 @@ then
 fi
 . ${virtualenv_activate}
 
-pip install -r dev-requirements.txt
-if [[ ! -e "./setup.py" ]]
+if [[ -e "./setup.py" ]]
 then
     python setup.py develop
 fi
